declare
  rq_id            numeric(16);
  rq_name          varchar2(256) := 'Fulfillment status for managed Applications';
  rqd              clob;
  counter          numeric(16);

begin


  rqd := '--Matched Accounts for managed Applications
'||'	select distinct pp.account_code as ACCOUNT_CODE,
'||'					case
'||'	                  when pwdm.is_default = 1 then
'||'	                   ''Default''
'||'					end as ACCOUNT_IS_DEFAULT,
'||'					pwdmType.name as ACCOUNT_TYPE,
'||'	                p.name as USER_NAME,
'||'	                p.surname as USER_SURNAME,
'||'	                p.code as USER_CODE,
'||'	                p.email as USER_EMAIL,
'||'	                p.dn as USER_DN,
'||'	                p.cod_fisc as USER_SSN,
'||'	                ou.name as GROUP_NAME,
'||'	                ou.code as GROUP_CODE,
'||'	                ou.description as GROUP_DESC,
'||'	                pp.target as TARGET,
'||'	                pp.permission_code as EXTERNAL_REF,
'||'	                pp.permission_type as PERMISSION_TYPE,
'||'	                e.name as ENTITLEMENT_NAME,
'||'	                e.code as ENTITLEMENT_CODE,
'||'	                e.description as ENTITLEMENT_DESC,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when pp.status = 0 then
'||'	                   ''Pending''
'||'	                  when pp.status = 1 then
'||'	                   ''Assignment - Pending Fulfillment''
'||'	                  when pp.status = 2 then
'||'	                   ''Assignment - Aligned''
'||'	                  when pp.status = 3 then
'||'	                   ''Assignment - Failed Fulfillment''
'||'	                  when pp.status = 4 then
'||'	                   ''Assignment - Target Originated''
'||'	                  when pp.status = 11 then
'||'	                   ''Removal - Pending Fulfillment''
'||'	                  when pp.status = 12 then
'||'	                   ''Removal - Aligned''
'||'	                  when pp.status = 13 then
'||'	                   ''Removal - Failed Fulfillment''
'||'	                  when pp.status = 14 then
'||'	                   ''Removal - Target Originated''
'||'	                  else
'||'	                   ''Unknown''
'||'	                end as STATUS,
'||'	                pp.verify_date as VERIFY_DATE
'||'	  from #pmschema#.person_profile pp
'||'	  left join #pmschema#.entitlement e
'||'	    on pp.profile = e.id
'||'	  left join #pmschema#.application a
'||'	    on e.application = a.id,
'||'	       #pmschema#.person p,
'||'	       #pmschema#.organizational_unit ou,
'||'	       #pmschema#.Target t,
'||'	       #pmschema#.Pwdcfg pc,
'||'		   #pmschema#.Pwdmanagement pwdm
'||'	  left join #pmschema#.pwdmanagement_type pwdmType
'||'	    on pwdm.pwdmanagement_type = pwdmType.id,
'||'	       #schema_tmp#.tmp_rep_application tmpa,
'||'	       #schema_tmp#.tmp_rep_organizational_unit tmpou
'||'	 where pp.person = p.id
'||'	   and p.organizational_unit = ou.id
'||'	   and pp.target = t.value
'||'	   and t.pwdcfg = pc.id
'||'	   and pwdm.pwdcfg = pc.id
'||'	   and pwdm.code = pp.account_code
'||'	   and pwdm.person = p.id
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   and a.id = tmpa.id
'||'	   and ou.id = tmpou.id
'||'	   and pp.status = #fulfillment_status#
'||'
'||'	union
'||'
'||'	--Matched Accounts for unmanaged Applications (without scope, visible by all the managers)
'||'	select distinct pp.account_code as ACCOUNT_CODE,
'||'					case
'||'	                  when pwdm.is_default = 1 then
'||'	                   ''Default''
'||'					end as ACCOUNT_IS_DEFAULT,
'||'					pwdmType.name as ACCOUNT_TYPE,
'||'	                p.name as USER_NAME,
'||'	                p.surname as USER_SURNAME,
'||'	                p.code as USER_CODE,
'||'	                p.email as USER_EMAIL,
'||'	                p.dn as USER_DN,
'||'	                p.cod_fisc as USER_SSN,
'||'	                ou.name as GROUP_NAME,
'||'	                ou.code as GROUP_CODE,
'||'	                ou.description as GROUP_DESC,
'||'	                pp.target as TARGET,
'||'	                pp.permission_code as EXTERNAL_REF,
'||'	                pp.permission_type as PERMISSION_TYPE,
'||'	                e.name as ENTITLEMENT_NAME,
'||'	                e.code as ENTITLEMENT_CODE,
'||'	                e.description as ENTITLEMENT_DESC,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when pp.status = 0 then
'||'	                   ''Pending''
'||'	                  when pp.status = 1 then
'||'	                   ''Assignment - Pending Fulfillment''
'||'	                  when pp.status = 2 then
'||'	                   ''Assignment - Aligned''
'||'	                  when pp.status = 3 then
'||'	                   ''Assignment - Failed Fulfillment''
'||'	                  when pp.status = 4 then
'||'	                   ''Assignment - Target Originated''
'||'	                  when pp.status = 11 then
'||'	                   ''Removal - Pending Fulfillment''
'||'	                  when pp.status = 12 then
'||'	                   ''Removal - Aligned''
'||'	                  when pp.status = 13 then
'||'	                   ''Removal - Failed Fulfillment''
'||'	                  when pp.status = 14 then
'||'	                   ''Removal - Target Originated''
'||'	                  else
'||'	                   ''Unknown''
'||'	                end as STATUS,
'||'	                pp.verify_date as VERIFY_DATE
'||'	  from #pmschema#.person_profile pp
'||'	  left join #pmschema#.entitlement e
'||'	    on pp.profile = e.id
'||'	  left join #pmschema#.application a
'||'	    on e.application = a.id,
'||'	       #pmschema#.person p,
'||'	       #pmschema#.organizational_unit ou,
'||'	       #pmschema#.Target t,
'||'	       #pmschema#.Pwdcfg pc,
'||'		   #pmschema#.Pwdmanagement pwdm
'||'	  left join #pmschema#.pwdmanagement_type pwdmType
'||'	    on pwdm.pwdmanagement_type = pwdmType.id,
'||'	       #schema_tmp#.tmp_rep_organizational_unit tmpou
'||'	 where e.id is null
'||'	   and pp.person = p.id
'||'	   and p.organizational_unit = ou.id
'||'	   and pp.target = t.value
'||'	   and t.pwdcfg = pc.id
'||'	   and pwdm.pwdcfg = pc.id
'||'	   and pwdm.code = pp.account_code
'||'	   and pwdm.person = p.id
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   and ou.id = tmpou.id
'||'	   and pp.status = #fulfillment_status#
'||'
'||'	union
'||'
'||'	--Unmatched Accounts for managed Applications
'||'	select distinct pp.account_code as ACCOUNT_CODE,
'||'	                case
'||'	                  when pwdm.is_default = 1 then
'||'	                   ''Default''
'||'					end as ACCOUNT_IS_DEFAULT,
'||'					pwdmType.name as ACCOUNT_TYPE,
'||'					p.name as USER_NAME,
'||'	                p.surname as USER_SURNAME,
'||'	                p.code as USER_CODE,
'||'	                p.email as USER_EMAIL,
'||'	                p.dn as USER_DN,
'||'	                p.cod_fisc as USER_SSN,
'||'	                ou.name as GROUP_NAME,
'||'	                ou.code as GROUP_CODE,
'||'	                ou.description as GROUP_DESC,
'||'	                pp.target as TARGET,
'||'	                pp.permission_code as EXTERNAL_REF,
'||'	                pp.permission_type as PERMISSION_TYPE,
'||'	                e.name as ENTITLEMENT_NAME,
'||'	                e.code as ENTITLEMENT_CODE,
'||'	                e.description as ENTITLEMENT_DESC,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when pp.status = 0 then
'||'	                   ''Pending''
'||'	                  when pp.status = 1 then
'||'	                   ''Assignment - Pending Fulfillment''
'||'	                  when pp.status = 2 then
'||'	                   ''Assignment - Aligned''
'||'	                  when pp.status = 3 then
'||'	                   ''Assignment - Failed Fulfillment''
'||'	                  when pp.status = 4 then
'||'	                   ''Assignment - Target Originated''
'||'	                  when pp.status = 11 then
'||'	                   ''Removal - Pending Fulfillment''
'||'	                  when pp.status = 12 then
'||'	                   ''Removal - Aligned''
'||'	                  when pp.status = 13 then
'||'	                   ''Removal - Failed Fulfillment''
'||'	                  when pp.status = 14 then
'||'	                   ''Removal - Target Originated''
'||'	                  else
'||'	                   ''Unknown''
'||'	                end as STATUS,
'||'	                pp.verify_date as VERIFY_DATE
'||'	  from #pmschema#.person_profile pp
'||'	  left join #pmschema#.person p
'||'	    on pp.person = p.id
'||'	  left join #pmschema#.entitlement e
'||'	    on pp.profile = e.id
'||'	  left join #pmschema#.organizational_unit ou
'||'	    on p.organizational_unit = ou.id
'||'	  left join #pmschema#.application a
'||'	    on e.application = a.id,
'||'	       #pmschema#.Target t,
'||'	       #pmschema#.Pwdcfg pc,
'||'		   #pmschema#.Pwdmanagement pwdm
'||'	  left join #pmschema#.pwdmanagement_type pwdmType
'||'	    on pwdm.pwdmanagement_type = pwdmType.id,
'||'	       #schema_tmp#.tmp_rep_application tmpa
'||'	 where p.id is null
'||'	   and pp.target = t.value
'||'	   and t.pwdcfg = pc.id
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   and a.id = tmpa.id
'||'	   and pp.status = #fulfillment_status#
'||'
'||'	union
'||'
'||'	--Unmatched Accounts for unmanaged Applications (without scope, visible by all the managers)
'||'	select distinct pp.account_code as ACCOUNT_CODE,
'||'					case
'||'	                  when pwdm.is_default = 1 then
'||'	                   ''Default''
'||'					end as ACCOUNT_IS_DEFAULT,
'||'					pwdmType.name as ACCOUNT_TYPE,
'||'					p.name as USER_NAME,
'||'	                p.surname as USER_SURNAME,
'||'	                p.code as USER_CODE,
'||'	                p.email as USER_EMAIL,
'||'	                p.dn as USER_DN,
'||'	                p.cod_fisc as USER_SSN,
'||'	                ou.name as GROUP_NAME,
'||'	                ou.code as GROUP_CODE,
'||'	                ou.description as GROUP_DESC,
'||'	                pp.target as TARGET,
'||'	                pp.permission_code as EXTERNAL_REF,
'||'	                pp.permission_type as PERMISSION_TYPE,
'||'	                e.name as ENTITLEMENT_NAME,
'||'	                e.code as ENTITLEMENT_CODE,
'||'	                e.description as ENTITLEMENT_DESC,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when pp.status = 0 then
'||'	                   ''Pending''
'||'	                  when pp.status = 1 then
'||'	                   ''Assignment - Pending Fulfillment''
'||'	                  when pp.status = 2 then
'||'	                   ''Assignment - Aligned''
'||'	                  when pp.status = 3 then
'||'	                   ''Assignment - Failed Fulfillment''
'||'	                  when pp.status = 4 then
'||'	                   ''Assignment - Target Originated''
'||'	                  when pp.status = 11 then
'||'	                   ''Removal - Pending Fulfillment''
'||'	                  when pp.status = 12 then
'||'	                   ''Removal - Aligned''
'||'	                  when pp.status = 13 then
'||'	                   ''Removal - Failed Fulfillment''
'||'	                  when pp.status = 14 then
'||'	                   ''Removal - Target Originated''
'||'	                  else
'||'	                   ''Unknown''
'||'	                end as STATUS,
'||'	                pp.verify_date as VERIFY_DATE
'||'	  from #pmschema#.person_profile pp
'||'	  left join #pmschema#.person p
'||'	    on pp.person = p.id
'||'	  left join #pmschema#.entitlement e
'||'	    on pp.profile = e.id
'||'	  left join #pmschema#.organizational_unit ou
'||'	    on p.organizational_unit = ou.id
'||'	  left join #pmschema#.application a
'||'	    on e.application = a.id,
'||'	       #pmschema#.Target t,
'||'	       #pmschema#.Pwdcfg pc,
'||'		   #pmschema#.Pwdmanagement pwdm
'||'	  left join #pmschema#.pwdmanagement_type pwdmType
'||'	    on pwdm.pwdmanagement_type = pwdmType.id
'||'	 where p.id is null
'||'	   and e.id is null
'||'	   and pp.target = t.value
'||'	   and t.pwdcfg = pc.id
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   and pp.status = #fulfillment_status#
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name );
  if ( counter = 1 ) then
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name );
    update r_query_data set query = rqd where r_query = rq_id;
  end if;
  
end;
/
commit;
