declare
  rq_id            numeric(16);
  rq_name          varchar2(256) := 'Certification - Fulfilment status report';
  rqd              clob;
  counter          numeric(16);

begin


  rqd := 'select distinct t.CAMPAIGN_NAME as CAMPAIGN_NAME,
'||'        t.CAMPAIGN_START as CAMPAIGN_START,
'||'        t.CAMPAIGN_END as CAMPAIGN_END,
'||'        t.CAMPAIGN_STATUS as CAMPAIGN_STATUS,
'||'        t.APPLICATION_NAME as APPLICATION_NAME,
'||'        t.ACCOUNT_CODE as ACCOUNT_CODE,
'||'        t.ACCOUNT_IS_DEFAULT as ACCOUNT_IS_DEFAULT,
'||'        t.ACCOUNT_CONFIGURATION as ACCOUNT_CONFIGURATION,
'||'        t.ENTITLEMENT_NAME as ENTITLEMENT_NAME,
'||'        t.PERMISSION_NAME as PERMISSION_NAME,
'||'        t.USER_CODE as USER_CODE,
'||'        t.USER_NAME as USER_NAME,
'||'        t.USER_SURNAME as USER_SURNAME,
'||'        t.OU_CODE as OU_CODE,
'||'        t.OU_NAME as OU_NAME,
'||'        t.NOTE as NOTE,
'||'        t.ACTION_NOTE as ACTION_NOTE,
'||'        t.ATTESTATION_STATUS as ATTESTATION_STATUS,
'||'        t.REVIEWED_BY_INFO REVIEWED_BY_INFO,
'||'        t.REVIEW_DATE as REVIEW_DATE,
'||'        t.REVOKE_FULFILLMENT as REVOKE_FULFILLMENT
'||'   from
'||'   (
'||'   select att.name as CAMPAIGN_NAME,
'||'          att.start_date as CAMPAIGN_START,
'||'          att.end_date as CAMPAIGN_END,
'||'          ''Active'' as CAMPAIGN_STATUS,
'||'          a.name as APPLICATION_NAME,
'||'          pwdm.code as ACCOUNT_CODE,
'||'          case
'||'            when pwdm.is_default = 1 then ''True'' 
'||'            when pwdm.is_default = 0 then ''False''
'||'            else ''Invalid''
'||'          end as ACCOUNT_IS_DEFAULT,
'||'          pwdcfg.name as ACCOUNT_CONFIGURATION,
'||'          e.name as ENTITLEMENT_NAME,
'||'          ep.name as PERMISSION_NAME,
'||'          p.code as USER_CODE,
'||'          p.name as USER_NAME,
'||'          p.surname as USER_SURNAME,
'||'          ou.code as OU_CODE,
'||'          ou.name as OU_NAME,
'||'          er.note as NOTE,
'||'          er.action_note as ACTION_NOTE,
'||'          case
'||'            when er.review_state = 0 then ''Not recertified yet''
'||'            when er.review_state = 1 then ''Approved''
'||'            when er.review_state = 2 or er.review_state = 3 then ''Revoked''
'||'            when er.review_state >= 10 then ''Other''
'||'          end as ATTESTATION_STATUS,
'||'          er.reviewed_by_info as REVIEWED_BY_INFO,
'||'          er.review_date as REVIEW_DATE,
'||'          case
'||'            when er.employment is NULL then ''Removed before sign off''
'||'            when er.review_state in ( 0, 1 ) then null
'||'            else ''Pending''
'||'          end as REVOKE_FULFILLMENT,
'||'          att.state as campaign_status_num,
'||'          ou.id as ou_id,
'||'          a.id as app_id
'||'     from #pmschema#.attestation              att,
'||'          #pmschema#.employment_review        er
'||'           left join #pmschema#.employment_pwdmanagement epwdm on epwdm.employment = er.employment
'||'           left join #pmschema#.pwdmanagement pwdm on epwdm.pwdmanagement = pwdm.id
'||'           left join #pmschema#.pwdcfg pwdcfg on pwdm.pwdcfg = pwdcfg.id
'||'           left join #pmschema#.target tar on pwdm.pwdcfg = tar.pwdcfg,
'||'          #pmschema#.person                   p,
'||'          #pmschema#.organizational_unit      ou,
'||'          #pmschema#.entitlement              e,
'||'          #pmschema#.entitlement_flat_hier  efh,
'||'		  #pmschema#.entitlement  ep
'||'          left join #pmschema#.application a on a.id = ep.application
'||'    where att.id = er.attestation
'||'      and att.type = 1
'||'      and er.person = p.id
'||'      AND (tar.id = a.TARGET OR er.employment IS null)
'||'      and p.organizational_unit = ou.id
'||'      and er.entitlement = e.id
'||'	  and cast(er.step as varchar) in (select attprop.value from #pmschema#.attestation_prop attprop where attprop.attestation = att.id and attprop.name = ''REVIEW_STEPS'')
'||'      and e.id = efh.parent
'||'      and efh.child_application = a.id
'||'      and efh.child_int_type = 1
'||'	  and ep.id = efh.child
'||'      and ou.hierarchy = 1
'||'      and (not exists
'||'	        (select 1 from #pmschema#.employment_review_h erh
'||'	        where erh.entitlement_name=e.name
'||'	        and erh.attestation_name=att.name
'||'	        and erh.person=er.person)
'||'        OR (
'||'        		e.INT_TYPE <> 3
'||'      		and not exists
'||'		        (select 1 from #pmschema#.employment_review_h erh
'||'		        where erh.entitlement_name=e.name
'||'		        and erh.application_name=a.name
'||'		        and erh.attestation_name=att.name
'||'		        and erh.person=er.person)))
'||'   union
'||'   select erh.attestation_name as CAMPAIGN_NAME,
'||'           null as CAMPAIGN_START,
'||'          null as CAMPAIGN_END,
'||'          ''Inactive'' as CAMPAIGN_STATUS,
'||'          a.name as APPLICATION_NAME,
'||'          case
'||'            when erph.pwdmanagement_code IS NOT NULL then erph.pwdmanagement_code
'||'            else ''N/A''
'||'          end as ACCOUNT_CODE,
'||'          case
'||'            when erph.is_default = 1 then ''True''  
'||'            when erph.is_default = 0 then ''False''
'||'            else ''N/A''
'||'          end as ACCOUNT_IS_DEFAULT,
'||'          case
'||'            when erph.pwdcfg_name IS NOT NULL then erph.pwdcfg_name
'||'            else ''N/A''
'||'          end as ACCOUNT_CONFIGURATION,
'||'          e.name as ENTITLEMENT_NAME,
'||'          perm.name as PERMISSION_NAME,
'||'          p.code as USER_CODE,
'||'          p.name as USER_NAME,
'||'          p.surname as USER_SURNAME,
'||'          ou.code as OU_CODE,
'||'          ou.name as OU_NAME,
'||'          erh.note as NOTE,
'||'          erh.action_note as ACTION_NOTE,
'||'          case
'||'            when erh.review_state = 0 then ''Not recertified''
'||'            when erh.review_state = 1 then ''Approved''
'||'            when erh.review_state = 2 or erh.review_state = 3 then ''Revoked''
'||'            when erh.review_state >= 10 then ''Other''
'||'          end as ATTESTATION_STATUS,
'||'          erh.cert_first_owner_name || '' '' || erh.cert_first_owner_surname || '' ('' || erh.cert_first_owner_code || '')'' as REVIEWED_BY_INFO,
'||'          erh.review_date as REVIEW_DATE,
'||'          case
'||'            when erh.review_state in ( 0, 1 ) then null
'||'            else ''Removed''
'||'          end as REVOKE_FULFILLMENT,
'||'          null as campaign_status_num,
'||'          ou.id as ou_id,
'||'          a.id as app_id
'||'     from #pmschema#.employment_review_h       erh,
'||'          #pmschema#.employment_review_pwdman_h erph,
'||'          #pmschema#.person                    p,
'||'          #pmschema#.organizational_unit       ou,
'||'          #pmschema#.entitlement               e,
'||'          #pmschema#.entitlement               perm,
'||'          #pmschema#.entitlement_flat_hier     efh,
'||'          #pmschema#.application               a,
'||'          #pmschema#.TARGET               tar,
'||'          #pmschema#.pwdcfg pwdcfg,
'||'	      #pmschema#.PWDMANAGEMENT pwdman
'||'    where erh.person = p.id
'||'      AND erph.employment_review_h = erh.id
'||'      AND erph.pwdcfg_name = pwdcfg.name
'||'      AND erph.PWDMANAGEMENT_CODE = pwdman.CODE
'||'      AND PWDMAN.PWDCFG = PWDCFG.id
'||'      AND a.TARGET = tar.ID
'||'      AND tar.PWDCFG = PWDCFG.id
'||'      and p.organizational_unit = ou.id
'||'      and erh.entitlement = e.id
'||'	  and erh.step = erh.total_steps
'||'      and e.id = efh.parent
'||'      and efh.child_application = a.id
'||'      and efh.child_int_type = 1
'||'      and ou.hierarchy = 1
'||'      AND perm.id = efh.CHILD
'||'UNION 
'||'(select erh.attestation_name as CAMPAIGN_NAME,
'||'          null as CAMPAIGN_START,
'||'          null as CAMPAIGN_END,
'||'          ''Inactive'' as CAMPAIGN_STATUS,
'||'          a.name as APPLICATION_NAME,
'||'          ''N/A'' as ACCOUNT_CODE,
'||'          ''N/A'' as ACCOUNT_IS_DEFAULT,
'||'          ''N/A'' as ACCOUNT_CONFIGURATION,
'||'          e.name as ENTITLEMENT_NAME,
'||'          perm.name as PERMISSION_NAME,
'||'          p.code as USER_CODE,
'||'          p.name as USER_NAME,
'||'          p.surname as USER_SURNAME,
'||'          ou.code as OU_CODE,
'||'          ou.name as OU_NAME,
'||'          erh.note as NOTE,
'||'          erh.action_note as ACTION_NOTE,
'||'          case
'||'            when erh.review_state = 0 then ''Not recertified''
'||'            when erh.review_state = 1 then ''Approved''
'||'            when erh.review_state = 2 or erh.review_state = 3 then ''Revoked''
'||'            when erh.review_state >= 10 then ''Other''
'||'          end as ATTESTATION_STATUS,
'||'          erh.cert_first_owner_name || '' '' || erh.cert_first_owner_surname || '' ('' || erh.cert_first_owner_code || '')'' as REVIEWED_BY_INFO,
'||'          erh.review_date as REVIEW_DATE,
'||'          case
'||'            when erh.review_state in ( 0, 1 ) then null
'||'            else ''Removed''
'||'          end as REVOKE_FULFILLMENT,
'||'          null as campaign_status_num,
'||'          ou.id as ou_id,
'||'          a.id as app_id
'||'     from #pmschema#.employment_review_h       erh,
'||'          #pmschema#.person                    p,
'||'          #pmschema#.organizational_unit       ou,
'||'          #pmschema#.entitlement               e,
'||'          #pmschema#.entitlement               perm,
'||'          #pmschema#.entitlement_flat_hier     efh,
'||'          #pmschema#.application               a
'||'    where erh.person = p.id
'||'      and p.organizational_unit = ou.id
'||'      and erh.entitlement = e.id
'||'	  and erh.step = erh.total_steps
'||'      and e.id = efh.parent
'||'      and efh.child_application = a.id
'||'      and efh.child_int_type = 1
'||'      and ou.hierarchy = 1
'||'      AND perm.id = efh.CHILD
'||'      and not exists
'||' 		(select 1 from #pmschema#.EMPLOYMENT_REVIEW_PWDMAN_H erph
'||' 		where erph.EMPLOYMENT_REVIEW_H=erh.id
'||' 		)
'||'      )      
'||'   union
'||'   select erh.attestation_name as CAMPAIGN_NAME,
'||'          null as CAMPAIGN_START,
'||'          null as CAMPAIGN_END,
'||'          ''Inactive'' as CAMPAIGN_STATUS,
'||'          erh.application_name as APPLICATION_NAME,
'||'          erph.pwdmanagement_code as ACCOUNT_CODE,
'||'          case
'||'            when erph.is_default = 1 then ''True'' 
'||'            when erph.is_default = 0 then ''False''
'||'            else ''Invalid''
'||'          end as ACCOUNT_IS_DEFAULT,
'||'          erph.pwdcfg_name as ACCOUNT_CONFIGURATION,
'||'          erh.entitlement_name as ENTITLEMENT_NAME,
'||'          ''N/A'' as PERMISSION_NAME,
'||'          p.code as USER_CODE,
'||'          p.name as USER_NAME,
'||'          p.surname as USER_SURNAME,
'||'          ou.code as OU_CODE,
'||'          ou.name as OU_NAME,
'||'          erh.note as NOTE,
'||'          erh.action_note as ACTION_NOTE,
'||'          case
'||'            when erh.review_state = 0 then ''Not recertified''
'||'            when erh.review_state = 1 then ''Approved''
'||'            when erh.review_state = 2 or erh.review_state = 3 then ''Revoked''
'||'            when erh.review_state >= 10 then ''Other''
'||'          end as ATTESTATION_STATUS,
'||'          null as REVIEWED_BY_INFO,
'||'          erh.review_date as REVIEW_DATE,
'||'          ''System deleted'' as REVOKE_FULFILLMENT,
'||'          null as campaign_status_num,
'||'          ou.id as ou_id,
'||'          null as app_id
'||'     from #pmschema#.employment_review_h       erh 
'||'		   left join #pmschema#.employment_review_pwdman_h erph ON erph.employment_review_h = erh.id,
'||'          #pmschema#.person                    p,
'||'          #pmschema#.organizational_unit       ou,
'||'          #pmschema#.application               a,
'||'          #pmschema#.target                    tar,
'||'          #pmschema#.pwdcfg                    pwdcfg
'||'    where erh.person = p.id
'||'      and p.organizational_unit = ou.id
'||'      and erh.entitlement is null
'||'	  and erh.step = erh.total_steps
'||'      and ou.hierarchy = 1
'||'      and a.target = tar.id
'||'      and pwdcfg.id = tar.pwdcfg
'||'      and pwdcfg.name = erph.pwdcfg_name
'||' ) t,
'||'   #schema_tmp#.tmp_rep_application tmp1,
'||'   #schema_tmp#.tmp_rep_organizational_unit tmp2
'||' where
'||'   lower(t.attestation_status) = lower(''#attestation_status#'')
'||'   and lower(t.revoke_fulfillment) = lower(''#revoke_fulfillment#'')
'||'   and (tmp1.id = t.app_id or t.app_id is null)
'||'   and tmp2.id = t.ou_id
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name );
  if ( counter = 1 ) then
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name );
    update r_query_data set query = rqd where r_query = rq_id;
  end if;
  
end;
/
commit;
