declare
  counter              number(16);

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'User Change Audit Report';
  r_desc               varchar2(512) := 'Generates a report for User add, modify and remove operations for a specified OU.';
  r_code               varchar2(256) := null;
  r_type         	   number(1) := 3;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'Audit User Change';

  rv_name              varchar2(256);
  repv_vis_type        number(2);

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  repfr_id             number(16);
  repfr_name_old       varchar2(256);
  repfr_name           varchar2(256);
  repfr_value          varchar2(256);
  repfr_l_id           number(16);
  repfr_l_code_old     varchar2(256);
  repfr_l_code         varchar2(256);
  repfr_i18n_msg       varchar2(256);
  repfr_vis            number(16);
  repfr_mand           number(16);
  repfr_type           number(16);
  repfr_multi          number(16);
  repfr_cust_id        number(16);
  repfr_cust_name      varchar2(256);
  repfr_posit_id       number(16);
  repfr_posit_id_old   number(16);

  cur_lan              sys_refcursor;
  lan_id               number(16);

  v_ret                number(16);

begin

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'NO QUERY FOUND' );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  end if;

  select count(1) into counter from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
  if ( counter = 0 ) then
    if ( r_loc_code is null ) then
      /*DBALT-BEGIN*/
      select dbms_random.random into r_loc_code from dual;
      /*PG*select trunc(random()*1000) into r_loc_code from generate_series(1,1000) limit 1;*PG*/
      /*select int((rand()-0.5) * 32768) into r_loc_code from dual;*/
      /*DBALT-END*/

      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 0 ) then
        select localization_seq.nextval into r_loc_id from dual;
        insert into localization ( id, code, code_type )
        values ( r_loc_id, r_loc_code, 0 );
      end if;

    else
      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 1 ) then
        select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
      end if;
    end if;

    if ( r_loc_id is null ) then
      select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
    end if;

    select max(id) + 1 into r_id from report t;

    insert into report ( id, name, description, localization, r_query, status, report_type, code, product, parent, dashboard )
    values ( r_id, r_name, r_desc, r_loc_id, rq_id, 0, r_type, r_code, 1, 1, r_dashboard );

    insert into report_attribute ( id, report, name, value )
    	values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'pdf' );
    insert into report_attribute ( id, report, name, value )
   	 	values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'xlsx' );
    insert into report_attribute ( id, report, name, value )
    	values ( report_attribute_seq.nextval, r_id, 'MAX_ROW', null );
   	insert into report_attribute ( id, report, name, value )
    	values ( report_attribute_seq.nextval, r_id, 'ORIENTATION', '1' );
    insert into report_attribute ( id, report, name, value )
    	values ( report_attribute_seq.nextval, r_id, 'PRIORITY', '0' );
  
  else
    select t.id, t.name into r_id, r_name from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
    select t.localization into r_loc_id from report t where t.id = r_id;
    update report set r_query = rq_id where id = r_id;
  end if;

  if ( r_i18n_mess is null or length ( r_i18n_mess ) = 0 ) then
    r_i18n_mess := r_name;
  end if;

  open cur_lan for select t.id from language t where t.language_status > 0;
  loop
    fetch cur_lan into lan_id;
    exit when cur_lan%NOTFOUND;

    select count(1) into counter from i18n_message t where t.language = lan_id and t.localization = r_loc_id;
    if ( counter = 0 ) then
      insert into i18n_message ( id, localization, language, message )
      values ( i18n_message_seq.nextval, r_loc_id, lan_id, r_i18n_mess );
    else
      update i18n_message set message = r_i18n_mess where language = lan_id and localization = r_loc_id;
    end if;
  end loop;
  close cur_lan;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'id';
  loc_rename      := true;
  i18n_msg        := 'ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'AUDIT_LOG';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'audit.log';
  loc_rename      := true;
  i18n_msg        := 'AUDIT_LOG';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
    -- Report FIELD 3
  rqf_name_old    := null;
  rqf_name        := 'OPERATOR';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'operator';
  loc_rename      := true;
  i18n_msg        := 'OPERATOR';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 4
  rqf_name_old    := null;
  rqf_name        := 'OPERATOR_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'operator.id';
  loc_rename      := true;
  i18n_msg        := 'OPERATOR_ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							
    -- Report FIELD 5
  rqf_name_old    := null;
  rqf_name        := 'EVENT_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'event.id';
  loc_rename      := true;
  i18n_msg        := 'EVENT_ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 6
  rqf_name_old    := null;
  rqf_name        := 'EVENT';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'event';
  loc_rename      := true;
  i18n_msg        := 'EVENT';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
    -- Report FIELD 7
  rqf_name_old    := null;
  rqf_name        := 'OPERATION_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'operation.code';
  loc_rename      := true;
  i18n_msg        := 'OPERATION_CODE';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 8
  rqf_name_old    := null;
  rqf_name        := 'EVENT_DATE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'event.date';
  loc_rename      := true;
  i18n_msg        := 'Event Date';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
  
    -- Report FIELD 9
  rqf_name_old    := null;
  rqf_name        := 'BENEFICIARY_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'beneficiary.type';
  loc_rename      := true;
  i18n_msg        := 'Type';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 10
  rqf_name_old    := null;
  rqf_name        := 'BENEFICIARY_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'beneficiary.id';
  loc_rename      := true;
  i18n_msg        := 'ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
    -- Report FIELD 11
  rqf_name_old    := null;
  rqf_name        := 'BENEFICIARY';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'beneficiary';
  loc_rename      := true;
  i18n_msg        := 'MasterUID';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 12
  rqf_name_old    := null;
  rqf_name        := 'BENEFICIARY_ATTR1';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'beneficiary.attr1';
  loc_rename      := true;
  i18n_msg        := 'First Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
  -- Report FIELD 13
  rqf_name_old    := null;
  rqf_name        := 'BENEFICIARY_ATTR2';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'beneficiary.attr2';
  loc_rename      := true;
  i18n_msg        := 'Last Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
  -- Report FIELD 14
  rqf_name_old    := null;
  rqf_name        := 'BENEFICIARY_ATTR3';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'beneficiary.attr3';
  loc_rename      := true;
  i18n_msg        := 'Organizational Unit';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 15
  rqf_name_old    := null;
  rqf_name        := 'ATTRIBUTE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'attribute';
  loc_rename      := true;
  i18n_msg        := 'ATTRIBUTE';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 16
  rqf_name_old    := null;
  rqf_name        := 'OLD_VALUE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'old.value';
  loc_rename      := true;
  i18n_msg        := 'OLD_VALUE';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 17
  rqf_name_old    := null;
  rqf_name        := 'NEW_VALUE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'new.value';
  loc_rename      := true;
  i18n_msg        := 'NEW_VALUE';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 18
  rqf_name_old    := null;
  rqf_name        := 'SOURCE_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'source.type';
  loc_rename      := true;
  i18n_msg        := 'SOURCE_TYPE';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 19
  rqf_name_old    := null;
  rqf_name        := 'SOURCE_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'source.id';
  loc_rename      := true;
  i18n_msg        := 'SOURCE_ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 20
  rqf_name_old    := null;
  rqf_name        := 'SOURCE_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'source.name';
  loc_rename      := true;
  i18n_msg        := 'SOURCE_NAME';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 21
  rqf_name_old    := null;
  rqf_name        := 'STATUS';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status';
  loc_rename      := true;
  i18n_msg        := 'STATUS';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 22
  rqf_name_old    := null;
  rqf_name        := 'STATUS_REASON';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status.reason';
  loc_rename      := true;
  i18n_msg        := 'STATUS_REASON';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 23
  rqf_name_old    := null;
  rqf_name        := 'ACTED_AS';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'acted.as';
  loc_rename      := true;
  i18n_msg        := 'ACTED_AS';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
   -- Report FIELD 24
  rqf_name_old    := null;
  rqf_name        := 'ACTED_AS_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'acted.as.id';
  loc_rename      := true;
  i18n_msg        := 'ACTED_AS_ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              

  -- QUERY AND REPORT VISIBILITY

  rv_name := 'AG-Core Org. Unit';
  repv_vis_type := 4;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  -- REPORT FILTERS
                              
  repfr_name_old     := null;
  repfr_name         := 'start_date';
  repfr_value        := '31536000000';
  repfr_l_code_old   := null;
  repfr_l_code       := 'start.date';
  repfr_i18n_msg     := 'Start date';
  repfr_vis          := 1;
  repfr_mand         := 1;
  repfr_type         := 1;
  repfr_multi        := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_multi, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );
                              
  repfr_name_old     := null;
  repfr_name         := 'end_date';
  repfr_value        := '4102358400000';
  repfr_l_code_old   := null;
  repfr_l_code       := 'end.date';
  repfr_i18n_msg     := 'End date';
  repfr_vis          := 1;
  repfr_mand         := 1;
  repfr_type         := 1;
  repfr_multi        := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_multi, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );
                              
  repfr_name_old     := null;
  repfr_name         := 'status';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'status.aud';
  repfr_i18n_msg     := 'STATUS';
  repfr_vis          := 1;
  repfr_mand         := 0;
  repfr_type         := 4;
  repfr_multi        := 1;
  repfr_cust_id      := null;
  repfr_cust_name    := 'Audit Status';
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_multi, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );
                              
  repfr_name_old     := null;
  repfr_name         := 'beneficiary';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'beneficiary';
  repfr_i18n_msg     := 'BENEFICIARY';
  repfr_vis          := 0;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_multi        := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_multi, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );
                              
  repfr_name_old     := null;
  repfr_name         := 'attribute';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'attribute';
  repfr_i18n_msg     := 'ATTRIBUTE';
  repfr_vis          := 0;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_multi        := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_multi, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );
                              
  repfr_name_old     := null;
  repfr_name         := 'operator';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'operator';
  repfr_i18n_msg     := 'OPERATOR';
  repfr_vis          := 0;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_multi        := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_multi, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

                              

end;
/
commit;
