#!/bin/bash

if [ -z "$ORACLE_SERVER" ]; then
  export ORACLE_SERVER=ORACLE_SERVER_TNS_NAME
fi

if [ -z "$SCHEMA_PWD" ]; then
  export SCHEMA_PWD=ideas
fi

if [ -z "$ORACLE_BASE" ]; then
  export ORACLE_BASE=/home/oracle
fi

if [ -z "$ORACLE_HOME" ]; then
  export ORACLE_HOME=$ORACLE_BASE/app/oracle/product/12.1.0/dbhome_1
fi

if [ -z "$SQLPLUS_CMD" ]; then
  export SQLPLUS_CMD=$ORACLE_HOME/bin/sqlplus
fi

UPGRADE_SCRIPT=$(cd $(dirname $0) && pwd)
CURRENT_DIR=$PWD

cd $UPGRADE_SCRIPT/AccessGovernanceCoreBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @va_app_perm.sql
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @agc_upgrade_80_to_81.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @agc_upgrade_80_to_81.sql
$SQLPLUS_CMD ccs_core/$SCHEMA_PWD@$ORACLE_SERVER @arc4s_upgrade_80_to_81.sql

cd $UPGRADE_SCRIPT/AccessRiskControlsForSAPBackend
$SQLPLUS_CMD ccs_core/$SCHEMA_PWD@$ORACLE_SERVER @arc4s_upgrade_50_to_51.sql

cd $UPGRADE_SCRIPT/AccessRequestsBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @arm_upgrade_20_to_21.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @arm_upgrade_20_to_21.sql

cd $UPGRADE_SCRIPT/AuditHelper
$SQLPLUS_CMD iga_service/$SCHEMA_PWD@$ORACLE_SERVER @audit_upgrade_40_to_41.sql

cd $UPGRADE_SCRIPT/DeskBackend
$SQLPLUS_CMD iga_service/$SCHEMA_PWD@$ORACLE_SERVER @desk_upgrade_30_to_31.sql

cd $UPGRADE_SCRIPT/ReportBackend
$SQLPLUS_CMD iga_report_admin/$SCHEMA_PWD@$ORACLE_SERVER @rd_upgrade_30_to_31.sql
$SQLPLUS_CMD iga_report_core/$SCHEMA_PWD@$ORACLE_SERVER @rd_upgrade_30_to_31.sql

cd $UPGRADE_SCRIPT/EmailBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @es_upgrade_30_to_31.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @es_upgrade_30_to_31.sql

cd $UPGRADE_SCRIPT/EnterpriseConnectorsBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @ec_upgrade_40_to_41.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @ec_upgrade_40_to_41.sql

cd $UPGRADE_SCRIPT/JobBackend
$SQLPLUS_CMD aa_admin/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_AA.sql
$SQLPLUS_CMD aa_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_AA.sql
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_AGC.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_AGC.sql
$SQLPLUS_CMD ccs_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_ARC4S.sql
$SQLPLUS_CMD iga_report_admin/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_REPORT.sql
$SQLPLUS_CMD iga_report_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_30_to_31_on_REPORT.sql

cd $UPGRADE_SCRIPT/Quartz
$SQLPLUS_CMD iga_quartz/$SCHEMA_PWD@$ORACLE_SERVER @quartz_upgrade_30_to_31.sql

cd $UPGRADE_SCRIPT/TaskPlannerBackend
$SQLPLUS_CMD iga_service/$SCHEMA_PWD@$ORACLE_SERVER @sk_upgrade_30_to_31.sql

cd $UPGRADE_SCRIPT/SIB_IB_ILC
$SQLPLUS_CMD itimuser/$SCHEMA_PWD@$ORACLE_SERVER @IB_ILC_upgrade.sql

cd $UPGRADE_SCRIPT/AccessGovernanceCoreBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @report_assignment.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @report_assignment.sql

cd $UPGRADE_SCRIPT/ReportBackend
$SQLPLUS_CMD iga_report_admin/$SCHEMA_PWD@$ORACLE_SERVER @revoke_from_agc.sql
$SQLPLUS_CMD iga_report_core/$SCHEMA_PWD@$ORACLE_SERVER @revoke_from_agc.sql

cd $UPGRADE_SCRIPT/Survey
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @survey.sql

cd $UPGRADE_SCRIPT/00-COMMON/Validation
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @version_validation.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @version_validation.sql

cd $CURRENT_DIR
