declare
  stat        varchar2(2048);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object

begin
  stat := '
  CREATE TABLE IB_RE_USERS (
    ID 					VARCHAR2(256) 	NOT NULL,
    EXTERNAL_ID 		VARCHAR2(256) 	NOT NULL,
    TARGET_ID 			VARCHAR2(256) 	NOT NULL,
    CREATED 			TIMESTAMP 		DEFAULT CURRENT_TIMESTAMP NOT NULL,
    LAST_MODIFIED 		TIMESTAMP 		DEFAULT CURRENT_TIMESTAMP NOT NULL,
    USER_NAME 			VARCHAR2(256),
    USER_NAME_LOWER 	VARCHAR2(256) 	GENERATED ALWAYS AS (LOWER(USER_NAME)) ,
    FORMATTED_NAME 		VARCHAR2(512),
    FAMILY_NAME 		VARCHAR2(256),
    GIVEN_NAME 			VARCHAR2(256),
    MIDDLE_NAME 		VARCHAR2(256),
    HONORIFIC_PREFIX 	VARCHAR2(128),
    HONORIFIC_SUFFIX 	VARCHAR2(128),
    DISPLAY_NAME 		VARCHAR2(256),
    NICK_NAME 			VARCHAR2(256),
    PROFILE_URL 		VARCHAR2(512),
    TITLE 				VARCHAR2(256),
    USER_TYPE 			VARCHAR2(256),
    PREFERRED_LANGUAGE 	VARCHAR2(64),
    LOCALE 				VARCHAR2(64),
    TIMEZONE 			VARCHAR2(64),
    ACTIVE 				VARCHAR2(8),
    EMPLOYEE_NUMBER 	VARCHAR2(256),
    COST_CENTER 		VARCHAR2(256),
    ORGANIZATION 		VARCHAR2(256),
    DIVISION 			VARCHAR2(256),
    DEPARTMENT 			VARCHAR2(256),
    MANAGER 			VARCHAR2(256),
    DIGEST 				VARCHAR2(64),
    SERIALIZED_VALUE 	CLOB,
    SERIALIZATION_TYPE 	VARCHAR2(16),
    VERSION VARCHAR2(64)
  )
    LOB (SERIALIZED_VALUE) STORE AS
    (
      TABLESPACE   &LOB_TABLESPACE
      ENABLE       STORAGE IN ROW
      CHUNK        8192
      NOCACHE
      INDEX IRU_SERIALIZED_VALUE_OBJ_IDX
      (
        TABLESPACE &LOB_TABLESPACE
      )
    )
  TABLESPACE &DATA_TABLESPACE
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-02260); -- PK already defined

begin
  stat := '
  ALTER TABLE IB_RE_USERS ADD (
    CONSTRAINT IB_RE_USERS_PK PRIMARY KEY (EXTERNAL_ID)
    USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object

begin
  stat := '
  CREATE INDEX IB_X_RE_USERS_USER_NAME ON IB_RE_USERS 
  (TARGET_ID, USER_NAME_LOWER)
  REVERSE
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

GRANT ALL ON IB_RE_USERS TO ITIMUSER;
GRANT SELECT ON IB_RE_USERS TO IDEAS_REPORT;

