declare
  stat        varchar2(2048);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object

begin
  stat := '
  CREATE TABLE PWDMANAGEMENT_STATUS
  (
	ID                             NUMBER(16)          NOT NULL,
  	PERSON                         NUMBER(16),
  	TARGET                         VARCHAR2(256 CHAR)  NOT NULL,
  	ACCOUNT_CODE                   VARCHAR2(256 CHAR)  NOT NULL,
 	PWDMANAGEMENT                  NUMBER(16),
 	PWDCFG		                   NUMBER(16)          NOT NULL,
  	STATUS                         NUMBER(16)          DEFAULT 0 NOT NULL,
  	VERIFY_DATE                    DATE,
  	STATUS_SUSPENSION              NUMBER(16)          DEFAULT 0 NOT NULL,
  	VERIFY_DATE_SUSPENSION         DATE,
  	STATUS_MODIFICATION            NUMBER(16)          DEFAULT 0 NOT NULL,
  	VERIFY_DATE_MODIFICATION       DATE,
  	STATUS_PASSWORD                NUMBER(16)          DEFAULT 0 NOT NULL,
  	VERIFY_DATE_PASSWORD           DATE,
  	SYNCH_MESSAGE                  VARCHAR2(256 CHAR),
  	CHANGELOG                      NUMERIC(16),
  	ATTR1                          VARCHAR2(256 CHAR),
  	ATTR2                          VARCHAR2(256 CHAR),
  	ATTR3                          VARCHAR2(256 CHAR),
  	ATTR4                          VARCHAR2(256 CHAR),
  	ATTR5                          VARCHAR2(256 CHAR),
  	CREATION_USER                  VARCHAR2(128 CHAR),
  	CREATION_DATE                  DATE                DEFAULT SYSDATE,
  	LAST_MOD_USER                  VARCHAR2(128 CHAR),
  	LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
  )
  TABLESPACE &DATA_TABLESPACE
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-02260); -- PK already defined

begin
  stat := '
  ALTER TABLE PWDMANAGEMENT_STATUS
    ADD CONSTRAINT PWDMANAGEMENT_STATUS_PK PRIMARY KEY (ID)
    USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

GRANT ALL ON PWDMANAGEMENT_STATUS TO IDEAS;
GRANT ALL ON PWDMANAGEMENT_STATUS TO IDEAS_CONNECTOR;
GRANT ALL ON PWDMANAGEMENT_STATUS TO IDEAS_REPORT;


declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object

begin
  stat := '
  CREATE SEQUENCE PWDMANAGEMENT_STATUS_SEQ
    START WITH 1
    INCREMENT BY 1
    MINVALUE 1
    MAXVALUE 999999999999999999999999999
    NOCACHE
    NOCYCLE
    NOORDER
    ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

GRANT ALL ON PWDMANAGEMENT_STATUS_SEQ TO IDEAS;
GRANT ALL ON PWDMANAGEMENT_STATUS_SEQ TO IDEAS_CONNECTOR;
GRANT ALL ON PWDMANAGEMENT_STATUS_SEQ TO IDEAS_REPORT;

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-02275); -- such a referential constraint already exists in the table

begin
  stat := '
 ALTER TABLE PWDMANAGEMENT_STATUS ADD (
  CONSTRAINT PWDMANAGEMENT_STATUS_PERSON_FK
 FOREIGN KEY (PERSON)
 REFERENCES PERSON (ID)
    ON DELETE CASCADE)
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-02275); -- such a referential constraint already exists in the table

begin
  stat := '
 ALTER TABLE PWDMANAGEMENT_STATUS ADD (
  CONSTRAINT PWDMANAGEMENT_STATUS_PWDMAN_FK
 FOREIGN KEY (PWDMANAGEMENT)
 REFERENCES PWDMANAGEMENT (ID)
    ON DELETE SET NULL)
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-02275); -- such a referential constraint already exists in the table

begin
  stat := '
 ALTER TABLE PWDMANAGEMENT_STATUS ADD (
  CONSTRAINT PWDMANAGEMENT_STATUS_PWDCFG_FK
 FOREIGN KEY (PWDCFG)
 REFERENCES PWDCFG (ID)
    ON DELETE CASCADE)
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_PERSON_IDX ON PWDMANAGEMENT_STATUS
  (PERSON)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_PWDMAN_IDX ON PWDMANAGEMENT_STATUS
  (PWDMANAGEMENT)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_PWDCFG_IDX ON PWDMANAGEMENT_STATUS
  (PWDCFG)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_ACCOUNT_IDX ON PWDMANAGEMENT_STATUS
  (ACCOUNT_CODE)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/


declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_IDX ON PWDMANAGEMENT_STATUS
  (STATUS)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_MODIFICATION_IDX ON PWDMANAGEMENT_STATUS
  (STATUS_MODIFICATION)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_PASSWORD_IDX ON PWDMANAGEMENT_STATUS
  (STATUS_PASSWORD)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
 
begin
  stat := '
  CREATE INDEX PWDMAN_STATUS_SUSPENSION_IDX ON PWDMANAGEMENT_STATUS
  (STATUS_SUSPENSION)
  NOLOGGING
  NOPARALLEL
  TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/


