declare
  counter              number(16);

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'Account fulfillment status for managed Applications';
  r_desc               varchar2(512) := 'Account Fulfillment status for all the Assignments related to Automatic and Manual Account Configurations. The scopes are set to view all Users and all the managed Applications. The report contains also not yet existing entilements in the system coming from target (so not of a specific Application, so out of the scope)';
  r_code               varchar2(256) := null;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'Account fulfillment status for managed Applications';
  rq_desc              varchar2(512) := 'Account Fulfillment status for all the Assignments related to Automatic and Manual Account Configurations. The scopes are set to view all Users and all the managed Applications. The report contains also not yet existing entilements in the system coming from target (so not of a specific Application, so out of the scope)';
  rqd                  clob;

  rv_name              varchar2(256);
  repv_vis_type        number(2);

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  repfr_id             number(16);
  repfr_name_old       varchar2(256);
  repfr_name           varchar2(256);
  repfr_value          varchar2(256);
  repfr_l_id           number(16);
  repfr_l_code_old     varchar2(256);
  repfr_l_code         varchar2(256);
  repfr_i18n_msg       varchar2(256);
  repfr_vis            number(16);
  repfr_mand           number(16);
  repfr_type           number(16);
  repfr_cust_id        number(16);
  repfr_cust_name      varchar2(256);
  repfr_posit_id       number(16);
  repfr_posit_id_old   number(16);
  
  cur_lan              sys_refcursor;
  lan_id               number(16);

  v_ret                number(16);

begin
  rqd := '-- Person and Account populated
'||'	select distinct ps.account_code as ACCOUNT_CODE,
'||'					case
'||'	                  when pwdm.is_default = 1 then
'||'	                   ''Default''
'||'	                  ELSE
'||'	                   ''No Default''
'||'					end as ACCOUNT_IS_DEFAULT,
'||'	                p.name as USER_NAME,
'||'	                p.surname as USER_SURNAME,
'||'	                p.code as USER_CODE,
'||'	                p.email as USER_EMAIL,
'||'	                p.dn as USER_DN,
'||'	                p.cod_fisc as USER_SSN,
'||'	                ou.name as GROUP_NAME,
'||'	                ou.code as GROUP_CODE,
'||'	                ou.description as GROUP_DESC,
'||'	                ps.target as TARGET,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when ps.status = 101 then
'||'	                   ''Creation - Pending Fulfillment''
'||'	                  when ps.status = 102 then
'||'	                   ''Creation - Aligned''
'||'	                  when ps.status = 103 then
'||'	                   ''Creation - Failed Fulfillment''
'||'	                  when ps.status = 104 then
'||'	                   ''Creation - Target Originated''
'||'	                  when ps.status = 111 then
'||'	                   ''Deletion - Pending Fulfillment''
'||'	                  when ps.status = 113 then
'||'	                   ''Deletion - Failed Fulfillment''
'||'	                  when ps.status = 114 then
'||'	                   ''Deletion - Target Originated''
'||'	                end as STATUS,
'||'	                ps.verify_date as VERIFY_DATE,
'||'	                case
'||'	                  when ps.status_suspension = 201 then
'||'	                   ''Restore - Pending Fulfillment''
'||'	                  when ps.status_suspension = 202 then
'||'	                   ''Restore - Aligned''
'||'	                  when ps.status_suspension = 203 then
'||'	                   ''Restore - Failed Fulfillment''
'||'	                  when ps.status_suspension = 204 then
'||'	                   ''Restore - Target Originated''
'||'	                  when ps.status_suspension = 211 then
'||'	                   ''Suspend - Pending Fulfillment''
'||'	                  when ps.status_suspension = 212 then
'||'	                   ''Suspend - Aligned''
'||'	                  when ps.status_suspension = 213 then
'||'	                   ''Suspend - Failed Fulfillment''
'||'	                  when ps.status_suspension = 214 then
'||'	                   ''Suspend - Target Originated''
'||'	                end as STATUS_SUSPENSION,
'||'	                ps.verify_date_suspension as VERIFY_DATE_SUSPENSION,
'||'	                case
'||'	                  when ps.status_modification = 301 then
'||'	                   ''Modify - Pending Fulfillment''
'||'	                  when ps.status_modification = 302 then
'||'	                   ''Modify - Aligned''
'||'	                  when ps.status_modification = 303 then
'||'	                   ''Modify - Faile Fulfillment''
'||'	                  when ps.status_modification = 304 then
'||'	                   ''Modify - Target Originated''
'||'	                end as STATUS_MODIFICATION,
'||'	                ps.verify_date_modification as VERIFY_DATE_MODIFICATION,
'||'	                case
'||'	                  when ps.status_password = 401 then
'||'	                   ''Change Password - Pending Fulfillment''
'||'	                  when ps.status_password = 402 then
'||'	                   ''Change Password - Aligned''
'||'	                  when ps.status_password = 403 then
'||'	                   ''Change Password - Faile Fulfillment''
'||'	                  when ps.status_password = 404 then
'||'	                   ''Change Password - Target Originated''
'||'	                end as STATUS_PASSWORD,
'||'	                ps.verify_date_password as VERIFY_DATE_PASSWORD
'||'	    from #pmschema#.PWDMANAGEMENT_STATUS ps left join #pmschema#.PWDMANAGEMENT pwdm
'||'   			on ps.PWDMANAGEMENT = pwdm.id
'||'  		left join #pmschema#.PWDCFG pc 
'||'  			on ps.PWDCFG = pc.ID
'||' 		left join #pmschema#.PERSON p 
'||' 			on ps.PERSON = p.ID
'||' 		left join #pmschema#.TARGET t 
'||' 			on ps.TARGET = t.NAME
'||' 		left join #pmschema#.application a on t.id = a.target,
'||'        		  #pmschema#.organizational_unit ou,
'||'          		  #schema_tmp#.tmp_rep_application tmpa,
'||'          		  #schema_tmp#.tmp_rep_organizational_unit tmpou
'||'	 where p.organizational_unit = ou.id
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'           and ps.person is not null
'||'	   and ps.pwdmanagement is not null
'||'	   and a.id = tmpa.id
'||'	   and ou.id = tmpou.id
'||'	   
'||'	   UNION
'||'     	
'||'	   -- Person populated and Account not populated
'||'     	select distinct ps.account_code as ACCOUNT_CODE,
'||'					''N/A'' as ACCOUNT_IS_DEFAULT,
'||'	                p.name as USER_NAME,
'||'	                p.surname as USER_SURNAME,
'||'	                p.code as USER_CODE,
'||'	                p.email as USER_EMAIL,
'||'	                p.dn as USER_DN,
'||'	                p.cod_fisc as USER_SSN,
'||'	                ou.name as GROUP_NAME,
'||'	                ou.code as GROUP_CODE,
'||'	                ou.description as GROUP_DESC,
'||'	                ps.target as TARGET,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when ps.status = 101 then
'||'	                   ''Creation - Pending Fulfillment''
'||'	                  when ps.status = 102 then
'||'	                   ''Creation - Aligned''
'||'	                  when ps.status = 103 then
'||'	                   ''Creation - Failed Fulfillment''
'||'	                  when ps.status = 104 then
'||'	                   ''Creation - Target Originated''
'||'	                  when ps.status = 111 then
'||'	                   ''Deletion - Pending Fulfillment''
'||'	                  when ps.status = 113 then
'||'	                   ''Deletion - Failed Fulfillment''
'||'	                  when ps.status = 114 then
'||'	                   ''Deletion - Target Originated''
'||'	                end as STATUS,
'||'	                ps.verify_date as VERIFY_DATE,
'||'	                case
'||'	                  when ps.status_suspension = 201 then
'||'	                   ''Restore - Pending Fulfillment''
'||'	                  when ps.status_suspension = 202 then
'||'	                   ''Restore - Aligned''
'||'	                  when ps.status_suspension = 203 then
'||'	                   ''Restore - Failed Fulfillment''
'||'	                  when ps.status_suspension = 204 then
'||'	                   ''Restore - Target Originated''
'||'	                  when ps.status_suspension = 211 then
'||'	                   ''Suspend - Pending Fulfillment''
'||'	                  when ps.status_suspension = 212 then
'||'	                   ''Suspend - Aligned''
'||'	                  when ps.status_suspension = 213 then
'||'	                   ''Suspend - Failed Fulfillment''
'||'	                  when ps.status_suspension = 214 then
'||'	                   ''Suspend - Target Originated''
'||'	                end as STATUS_SUSPENSION,
'||'	                ps.verify_date_suspension as VERIFY_DATE_SUSPENSION,
'||'	                case
'||'	                  when ps.status_modification = 301 then
'||'	                   ''Modify - Pending Fulfillment''
'||'	                  when ps.status_modification = 302 then
'||'	                   ''Modify - Aligned''
'||'	                  when ps.status_modification = 303 then
'||'	                   ''Modify - Faile Fulfillment''
'||'	                  when ps.status_modification = 304 then
'||'	                   ''Modify - Target Originated''
'||'	                end as STATUS_MODIFICATION,
'||'	                ps.verify_date_modification as VERIFY_DATE_MODIFICATION,
'||'	                case
'||'	                  when ps.status_password = 401 then
'||'	                   ''Change Password - Pending Fulfillment''
'||'	                  when ps.status_password = 402 then
'||'	                   ''Change Password - Aligned''
'||'	                  when ps.status_password = 403 then
'||'	                   ''Change Password - Faile Fulfillment''
'||'	                  when ps.status_password = 404 then
'||'	                   ''Change Password - Target Originated''
'||'	                end as STATUS_PASSWORD,
'||'	                ps.verify_date_password as VERIFY_DATE_PASSWORD
'||'	    from #pmschema#.PWDMANAGEMENT_STATUS ps 
'||'  		left join #pmschema#.PWDCFG pc 
'||'  			on ps.PWDCFG = pc.ID
'||' 		left join #pmschema#.PERSON p 
'||' 			on ps.PERSON = p.ID
'||' 		left join #pmschema#.TARGET t 
'||' 			on ps.TARGET = t.NAME
'||' 		left join #pmschema#.application a on t.id = a.target,
'||'        		  #pmschema#.organizational_unit ou,
'||'          		  #schema_tmp#.tmp_rep_organizational_unit tmpou
'||'	 where p.organizational_unit = ou.id
'||'	   AND ps.PWDMANAGEMENT IS NULL
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   and ou.id = tmpou.id
'||'	
'||'	   UNION
'||'	   
'||'	   -- Person not populated and Account not populated
'||'     	select distinct ps.account_code as ACCOUNT_CODE,
'||'					''N/A'' as ACCOUNT_IS_DEFAULT,
'||'	                ''N/A'' as USER_NAME,
'||'	                ''N/A'' as USER_SURNAME,
'||'	                ''N/A'' as USER_CODE,
'||'	                ''N/A'' as USER_EMAIL,
'||'	                ''N/A'' as USER_DN,
'||'	                ''N/A'' as USER_SSN,
'||'	                ''N/A'' as GROUP_NAME,
'||'	                ''N/A'' as GROUP_CODE,
'||'	                ''N/A'' as GROUP_DESC,
'||'	                ps.target as TARGET,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when ps.status = 101 then
'||'	                   ''Creation - Pending Fulfillment''
'||'	                  when ps.status = 102 then
'||'	                   ''Creation - Aligned''
'||'	                  when ps.status = 103 then
'||'	                   ''Creation - Failed Fulfillment''
'||'	                  when ps.status = 104 then
'||'	                   ''Creation - Target Originated''
'||'	                  when ps.status = 111 then
'||'	                   ''Deletion - Pending Fulfillment''
'||'	                  when ps.status = 113 then
'||'	                   ''Deletion - Failed Fulfillment''
'||'	                  when ps.status = 114 then
'||'	                   ''Deletion - Target Originated''
'||'	                end as STATUS,
'||'	                ps.verify_date as VERIFY_DATE,
'||'	                case
'||'	                  when ps.status_suspension = 201 then
'||'	                   ''Restore - Pending Fulfillment''
'||'	                  when ps.status_suspension = 202 then
'||'	                   ''Restore - Aligned''
'||'	                  when ps.status_suspension = 203 then
'||'	                   ''Restore - Failed Fulfillment''
'||'	                  when ps.status_suspension = 204 then
'||'	                   ''Restore - Target Originated''
'||'	                  when ps.status_suspension = 211 then
'||'	                   ''Suspend - Pending Fulfillment''
'||'	                  when ps.status_suspension = 212 then
'||'	                   ''Suspend - Aligned''
'||'	                  when ps.status_suspension = 213 then
'||'	                   ''Suspend - Failed Fulfillment''
'||'	                  when ps.status_suspension = 214 then
'||'	                   ''Suspend - Target Originated''
'||'	                end as STATUS_SUSPENSION,
'||'	                ps.verify_date_suspension as VERIFY_DATE_SUSPENSION,
'||'	                case
'||'	                  when ps.status_modification = 301 then
'||'	                   ''Modify - Pending Fulfillment''
'||'	                  when ps.status_modification = 302 then
'||'	                   ''Modify - Aligned''
'||'	                  when ps.status_modification = 303 then
'||'	                   ''Modify - Faile Fulfillment''
'||'	                  when ps.status_modification = 304 then
'||'	                   ''Modify - Target Originated''
'||'	                end as STATUS_MODIFICATION,
'||'	                ps.verify_date_modification as VERIFY_DATE_MODIFICATION,
'||'	                case
'||'	                  when ps.status_password = 401 then
'||'	                   ''Change Password - Pending Fulfillment''
'||'	                  when ps.status_password = 402 then
'||'	                   ''Change Password - Aligned''
'||'	                  when ps.status_password = 403 then
'||'	                   ''Change Password - Faile Fulfillment''
'||'	                  when ps.status_password = 404 then
'||'	                   ''Change Password - Target Originated''
'||'	                end as STATUS_PASSWORD,
'||'	                ps.verify_date_password as VERIFY_DATE_PASSWORD
'||'	    from #pmschema#.PWDMANAGEMENT_STATUS ps 
'||'  		left join #pmschema#.PWDCFG pc 
'||'  			on ps.PWDCFG = pc.ID
'||' 		left join #pmschema#.TARGET t 
'||' 			on ps.TARGET = t.NAME
'||' 		left join #pmschema#.application a on t.id = a.target
'||'	 where ps.PWDMANAGEMENT IS NULL
'||'	   AND ps.PERSON IS NULL
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   
'||'	   UNION
'||'	   
'||'	   -- Person not populated and Account populated
'||'	select distinct ps.account_code as ACCOUNT_CODE,
'||'					case
'||'	                  when pwdm.is_default = 1 then
'||'	                   ''Default''
'||'	                  ELSE
'||'	                   ''No Default''
'||'					end as ACCOUNT_IS_DEFAULT,
'||'	                ''N/A'' as USER_NAME,
'||'	                ''N/A'' as USER_SURNAME,
'||'	                ''N/A'' as USER_CODE,
'||'	                ''N/A'' as USER_EMAIL,
'||'	                ''N/A'' as USER_DN,
'||'	                ''N/A'' as USER_SSN,
'||'	                ''N/A'' as GROUP_NAME,
'||'	                ''N/A'' as GROUP_CODE,
'||'	                ''N/A'' as GROUP_DESC,
'||'	                ps.target as TARGET,
'||'	                a.name as APPLICATION_NAME,
'||'	                case
'||'	                  when ps.status = 101 then
'||'	                   ''Creation - Pending Fulfillment''
'||'	                  when ps.status = 102 then
'||'	                   ''Creation - Aligned''
'||'	                  when ps.status = 103 then
'||'	                   ''Creation - Failed Fulfillment''
'||'	                  when ps.status = 104 then
'||'	                   ''Creation - Target Originated''
'||'	                  when ps.status = 111 then
'||'	                   ''Deletion - Pending Fulfillment''
'||'	                  when ps.status = 113 then
'||'	                   ''Deletion - Failed Fulfillment''
'||'	                  when ps.status = 114 then
'||'	                   ''Deletion - Target Originated''
'||'	                end as STATUS,
'||'	                ps.verify_date as VERIFY_DATE,
'||'	                case
'||'	                  when ps.status_suspension = 201 then
'||'	                   ''Restore - Pending Fulfillment''
'||'	                  when ps.status_suspension = 202 then
'||'	                   ''Restore - Aligned''
'||'	                  when ps.status_suspension = 203 then
'||'	                   ''Restore - Failed Fulfillment''
'||'	                  when ps.status_suspension = 204 then
'||'	                   ''Restore - Target Originated''
'||'	                  when ps.status_suspension = 211 then
'||'	                   ''Suspend - Pending Fulfillment''
'||'	                  when ps.status_suspension = 212 then
'||'	                   ''Suspend - Aligned''
'||'	                  when ps.status_suspension = 213 then
'||'	                   ''Suspend - Failed Fulfillment''
'||'	                  when ps.status_suspension = 214 then
'||'	                   ''Suspend - Target Originated''
'||'	                end as STATUS_SUSPENSION,
'||'	                ps.verify_date_suspension as VERIFY_DATE_SUSPENSION,
'||'	                case
'||'	                  when ps.status_modification = 301 then
'||'	                   ''Modify - Pending Fulfillment''
'||'	                  when ps.status_modification = 302 then
'||'	                   ''Modify - Aligned''
'||'	                  when ps.status_modification = 303 then
'||'	                   ''Modify - Faile Fulfillment''
'||'	                  when ps.status_modification = 304 then
'||'	                   ''Modify - Target Originated''
'||'	                end as STATUS_MODIFICATION,
'||'	                ps.verify_date_modification as VERIFY_DATE_MODIFICATION,
'||'	                case
'||'	                  when ps.status_password = 401 then
'||'	                   ''Change Password - Pending Fulfillment''
'||'	                  when ps.status_password = 402 then
'||'	                   ''Change Password - Aligned''
'||'	                  when ps.status_password = 403 then
'||'	                   ''Change Password - Faile Fulfillment''
'||'	                  when ps.status_password = 404 then
'||'	                   ''Change Password - Target Originated''
'||'	                end as STATUS_PASSWORD,
'||'	                ps.verify_date_password as VERIFY_DATE_PASSWORD
'||'	    from #pmschema#.PWDMANAGEMENT_STATUS ps left join #pmschema#.PWDMANAGEMENT pwdm
'||'   			on ps.PWDMANAGEMENT = pwdm.id
'||'  		left join #pmschema#.PWDCFG pc 
'||'  			on ps.PWDCFG = pc.ID
'||' 		left join #pmschema#.TARGET t 
'||' 			on ps.TARGET = t.NAME
'||' 		left join #pmschema#.application a on t.id = a.target,
'||'          		  #schema_tmp#.tmp_rep_application tmpa
'||'	 where ps.PERSON IS null
'||'           and ps.PWDMANAGEMENT is not null
'||'	   and (pc.sync = 2 or pc.sync = 1)
'||'	   and a.id = tmpa.id
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query set description = rq_desc where id = rq_id;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  select count(1) into counter from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
  if ( counter = 0 ) then
    if ( r_loc_code is null ) then
      /*DBALT-BEGIN*/
      select dbms_random.random into r_loc_code from dual;
      /*PG*select trunc(random()*1000) into r_loc_code from generate_series(1,1000) limit 1;*PG*/
      /*select int((rand()-0.5) * 32768) into r_loc_code from dual;*/
      /*DBALT-END*/

      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 0 ) then
        select localization_seq.nextval into r_loc_id from dual;
        insert into localization ( id, code, code_type )
        values ( r_loc_id, r_loc_code, 0 );
      end if;

    else
      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 1 ) then
        select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
      end if;
    end if;

    if ( r_loc_id is null ) then
      select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
    end if;

    select max(id) + 1 into r_id from report t;

    insert into report ( id, name, description, localization, r_query, status, report_type, code, product, parent, dashboard )
    values ( r_id, r_name, r_desc, r_loc_id, rq_id, 0, null, r_code, 1, 1, r_dashboard );

    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'pdf' );
    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'xlsx' );
    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'csv' );
    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'MAX_ROW', null );
    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'ORIENTATION', '1' );
  
    
  else
    select t.id, t.name into r_id, r_name from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
    select t.localization into r_loc_id from report t where t.id = r_id;
    update report set r_query = rq_id where id = r_id;
  end if;

  if ( r_i18n_mess is null or length ( r_i18n_mess ) = 0 ) then
    r_i18n_mess := r_name;
  end if;

  open cur_lan for select t.id from language t where t.language_status > 0;
  loop
    fetch cur_lan into lan_id;
    exit when cur_lan%NOTFOUND;

    select count(1) into counter from i18n_message t where t.language = lan_id and t.localization = r_loc_id;
    if ( counter = 0 ) then
      insert into i18n_message ( id, localization, language, message )
      values ( i18n_message_seq.nextval, r_loc_id, lan_id, r_i18n_mess );
    else
      update i18n_message set message = r_i18n_mess where language = lan_id and localization = r_loc_id;
    end if;
  end loop;
  close cur_lan;
  
  
  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.code';
  loc_rename      := true;
  i18n_msg        := 'Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := 0;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
    -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_IS_DEFAULT';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.isdefault';
  loc_rename      := true;
  i18n_msg        := 'Is Default';
  repf_pos_id_old := null;
  repf_pos_id     := 1;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

                                    
  -- Report FIELD 3
  rqf_name_old    := null;
  rqf_name        := 'USER_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.name';
  loc_rename      := true;
  i18n_msg        := 'First Name';
  repf_pos_id_old := null;
  repf_pos_id     := 2;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
  -- Report FIELD 4
  rqf_name_old    := null;
  rqf_name        := 'USER_SURNAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.surname';
  loc_rename      := true;
  i18n_msg        := 'Last Name';
  repf_pos_id_old := null;
  repf_pos_id     := 3;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
  -- Report FIELD 5
  rqf_name_old    := null;
  rqf_name        := 'USER_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.code';
  loc_rename      := true;
  i18n_msg        := 'UserID';
  repf_pos_id_old := null;
  repf_pos_id     := 4;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
  -- Report FIELD 6
  rqf_name_old    := null;
  rqf_name        := 'USER_EMAIL';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.email';
  loc_rename      := true;
  i18n_msg        := 'Email';
  repf_pos_id_old := null;
  repf_pos_id     := 5;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
                              
  -- Report FIELD 7
  rqf_name_old    := null;
  rqf_name        := 'USER_DN';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.dn';
  loc_rename      := true;
  i18n_msg        := 'User DN';
  repf_pos_id_old := null;
  repf_pos_id     := 6;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              
  -- Report FIELD 8
  rqf_name_old    := null;
  rqf_name        := 'USER_SSN';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.ssn';
  loc_rename      := true;
  i18n_msg        := 'SSN Code';
  repf_pos_id_old := null;
  repf_pos_id     := 7;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 9
  rqf_name_old    := null;
  rqf_name        := 'GROUP_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.name';
  loc_rename      := true;
  i18n_msg        := 'Group';
  repf_pos_id_old := null;
  repf_pos_id     := 8;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 10
  rqf_name_old    := null;
  rqf_name        := 'GROUP_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.code';
  loc_rename      := true;
  i18n_msg        := 'GROUP_CODE';
  repf_pos_id_old := null;
  repf_pos_id     := 9;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 11
  rqf_name_old    := null;
  rqf_name        := 'GROUP_DESC';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.desc';
  loc_rename      := true;
  i18n_msg        := 'Group descr.';
  repf_pos_id_old := null;
  repf_pos_id     := 10;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 12
  rqf_name_old    := null;
  rqf_name        := 'TARGET';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'target';
  loc_rename      := true;
  i18n_msg        := 'Target';
  repf_pos_id_old := null;
  repf_pos_id     := 11;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 13
  rqf_name_old    := null;
  rqf_name        := 'APPLICATION_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'application.name';
  loc_rename      := true;
  i18n_msg        := 'Application';
  repf_pos_id_old := null;
  repf_pos_id     := 12;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 14
  rqf_name_old    := null;
  rqf_name        := 'STATUS';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status';
  loc_rename      := true;
  i18n_msg        := 'Sync Status';
  repf_pos_id_old := null;
  repf_pos_id     := 13;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 15
  rqf_name_old    := null;
  rqf_name        := 'VERIFY_DATE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'verify.date';
  loc_rename      := true;
  i18n_msg        := 'Verified';
  repf_pos_id_old := null;
  repf_pos_id     := 14;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 16
  rqf_name_old    := null;
  rqf_name        := 'STATUS_SUSPENSION';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status.suspension';
  loc_rename      := true;
  i18n_msg        := 'Suspension Status';
  repf_pos_id_old := null;
  repf_pos_id     := 15;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 17
  rqf_name_old    := null;
  rqf_name        := 'VERIFY_DATE_SUSPENSION';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'verify.date.suspension';
  loc_rename      := true;
  i18n_msg        := 'Suspension Verify Date';
  repf_pos_id_old := null;
  repf_pos_id     := 16;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 18
  rqf_name_old    := null;
  rqf_name        := 'STATUS_MODIFICATION';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status.modification';
  loc_rename      := true;
  i18n_msg        := 'Modification Status';
  repf_pos_id_old := null;
  repf_pos_id     := 17;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 19
  rqf_name_old    := null;
  rqf_name        := 'VERIFY_DATE_MODIFICATION';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'verify.date.modification';
  loc_rename      := true;
  i18n_msg        := 'Modification Verify Date';
  repf_pos_id_old := null;
  repf_pos_id     := 18;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );                              
                              

  -- Report FIELD 20
  rqf_name_old    := null;
  rqf_name        := 'STATUS_PASSWORD';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status.password';
  loc_rename      := true;
  i18n_msg        := 'Password Status';
  repf_pos_id_old := null;
  repf_pos_id     := 19;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );     
                              
                                
  -- Report FIELD 21
  rqf_name_old    := null;
  rqf_name        := 'VERIFY_DATE_PASSWORD';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'verify.date.password';
  loc_rename      := true;
  i18n_msg        := 'Password Verify Date';
  repf_pos_id_old := null;
  repf_pos_id     := 20;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );     
                              
  --QUERY VISIBILITY AND REPORT VISIBILITY 01: BEGIN
  rv_name := 'AG-Core Application';
  repv_vis_type := 2;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  rv_name := 'AG-Core Org. Unit';
  repv_vis_type := 2;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );
  

end;
/
commit;

