#!/bin/bash

if [ -z "$ORACLE_SERVER" ]; then
  export ORACLE_SERVER=ORACLE_SERVER_TNS_NAME
fi

if [ -z "$SCHEMA_PWD" ]; then
  export SCHEMA_PWD=ideas
fi

if [ -z "$ORACLE_BASE" ]; then
  export ORACLE_BASE=/home/oracle
fi

if [ -z "$ORACLE_HOME" ]; then
  export ORACLE_HOME=$ORACLE_BASE/app/oracle/product/12.1.0/dbhome_1
fi

if [ -z "$SQLPLUS_CMD" ]; then
  export SQLPLUS_CMD=$ORACLE_HOME/bin/sqlplus
fi

UPGRADE_SCRIPT=$(cd $(dirname $0) && pwd)
CURRENT_DIR=$PWD

cd $UPGRADE_SCRIPT/AccessGovernanceCoreBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @va_app_perm.sql
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @agc_upgrade_78_to_79.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @agc_upgrade_78_to_79.sql
$SQLPLUS_CMD ccs_core/$SCHEMA_PWD@$ORACLE_SERVER @arc4s_upgrade_78_to_79.sql

cd $UPGRADE_SCRIPT/AccessRiskControlsForSAPBackend
$SQLPLUS_CMD ccs_core/$SCHEMA_PWD@$ORACLE_SERVER @arc4s_upgrade_48_to_49.sql

cd $UPGRADE_SCRIPT/AccessRequestsBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @arm_upgrade_18_to_19.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @arm_upgrade_18_to_19.sql

cd $UPGRADE_SCRIPT/AuditHelper
$SQLPLUS_CMD iga_service/$SCHEMA_PWD@$ORACLE_SERVER @audit_upgrade_38_to_39.sql

cd $UPGRADE_SCRIPT/DeskBackend
$SQLPLUS_CMD iga_service/$SCHEMA_PWD@$ORACLE_SERVER @desk_upgrade_28_to_29.sql

cd $UPGRADE_SCRIPT/ReportBackend
$SQLPLUS_CMD iga_report_admin/$SCHEMA_PWD@$ORACLE_SERVER @rd_upgrade_28_to_29.sql
$SQLPLUS_CMD iga_report_core/$SCHEMA_PWD@$ORACLE_SERVER @rd_upgrade_28_to_29.sql

cd $UPGRADE_SCRIPT/EmailBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @es_upgrade_28_to_29.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @es_upgrade_28_to_29.sql

cd $UPGRADE_SCRIPT/EnterpriseConnectorsBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @ec_upgrade_38_to_39.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @ec_upgrade_38_to_39.sql

cd $UPGRADE_SCRIPT/JobBackend
$SQLPLUS_CMD aa_admin/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_AA.sql
$SQLPLUS_CMD aa_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_AA.sql
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_AGC.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_AGC.sql
$SQLPLUS_CMD ccs_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_ARC4S.sql
$SQLPLUS_CMD iga_report_admin/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_REPORT.sql
$SQLPLUS_CMD iga_report_core/$SCHEMA_PWD@$ORACLE_SERVER @job_upgrade_28_to_29_on_REPORT.sql

cd $UPGRADE_SCRIPT/Quartz
$SQLPLUS_CMD iga_quartz/$SCHEMA_PWD@$ORACLE_SERVER @quartz_upgrade_28_to_29.sql

cd $UPGRADE_SCRIPT/TaskPlannerBackend
$SQLPLUS_CMD iga_service/$SCHEMA_PWD@$ORACLE_SERVER @sk_upgrade_28_to_29.sql

cd $UPGRADE_SCRIPT/SIB_IB_ILC
$SQLPLUS_CMD itimuser/$SCHEMA_PWD@$ORACLE_SERVER @IB_ILC_upgrade.sql

cd $UPGRADE_SCRIPT/AccessGovernanceCoreBackend
$SQLPLUS_CMD iga_admin/$SCHEMA_PWD@$ORACLE_SERVER @report_assignment.sql
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @report_assignment.sql

cd $UPGRADE_SCRIPT/ReportBackend
$SQLPLUS_CMD iga_report_admin/$SCHEMA_PWD@$ORACLE_SERVER @revoke_from_agc.sql
$SQLPLUS_CMD iga_report_core/$SCHEMA_PWD@$ORACLE_SERVER @revoke_from_agc.sql

cd $UPGRADE_SCRIPT/Survey
$SQLPLUS_CMD iga_core/$SCHEMA_PWD@$ORACLE_SERVER @survey.sql

cd $CURRENT_DIR
